@@ -77,11 +77,14 @@ def mysql_args(db, user, passwd, host, port):
 
 
 def do_mysql_backup(args, outfile):
-    os.system('mysqldump %s > %s' % (' '.join(args), outfile))
+    if getattr(settings, 'SCRIPT_BACKUPDB', None):
+        os.system('%s %s %s' % (settings.SCRIPT_BACKUPDB, ' '.join(args), outfile))
+    else:
+        os.system('mysqldump %s > %s' % (' '.join(args), outfile))
 
 
 def postgresql_args(db, user, passwd, host, port):
-    args = ['pg_dump']
+    args = []
     if user:
         args += ["--username=%s" % user]
     if passwd:
@@ -97,18 +100,21 @@ def postgresql_args(db, user, passwd, host, port):
 
 def do_postgresql_backup(args, passwd, outfile):
     import pexpect
-
-    cmd = ' '.join(args)
-    if passwd:
-        child = pexpect.spawn(' '.join(args), timeout=1000)
-        child.expect("\s*:")  # pg_dump ask for the password here
-        child.sendline(passwd)
-
-        child.expect(pexpect.EOF)
-        file(outfile, "w").write(child.before)
-        child.close()
+    args = ' '.join(args)
+    if getattr(settings, 'SCRIPT_BACKUPDB', None):
+        os.system('%s %s %s' % (settings.SCRIPT_BACKUPDB, ' '.join(args), outfile))
     else:
-        os.system('%s > %s' % (cmd, outfile))
+        cmd = 'pg_dump %s' % args
+        if passwd:
+            child = pexpect.spawn(cmd, timeout=1000)
+            child.expect("\s*:")  # pg_dump ask for the password here
+            child.sendline(passwd)
+
+            child.expect(pexpect.EOF)
+            file(outfile, "w").write(child.before)
+            child.close()
+        else:
+            os.system('%s > %s' % (cmd, outfile))
 
 
 def set_backup(db):
